<?php
/**
 * Widget_chart widget class
 *
 * @since 2.8.0
 */
add_action( 'widgets_init', 'themerex_chart_widget' );

function themerex_chart_widget() {
	register_widget( 'Themerex_Chart_Widget' );
}
 
class Themerex_Chart_Widget extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'widget_chart', 'description' => __( 'Themerex Widget Chart' , 'themerex') );
		parent::__construct('themerex-widget-chart', __('Themerex Charts', 'themerex'), $widget_ops);
		$this->alt_option_name = 'widget_chart';
		wp_enqueue_script( 'wp-color-picker' );
	}
	
	function widget( $args, $instance ) {
		
		$output = '';
		
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}
		
		$block_id = '';
		$alphas = range('a', 'z');
   		for( $i = 0; $i < 12; $i++ ) {
   			$block_id .= $alphas[rand(0, 25)];
   		}
   		
		$chart_childs = array();
		
		$chart_type = $instance['type'];	
		$title = apply_filters('widget_title', $instance['title'] );
		$iter_count = 0;
		if(!empty($instance['chart_item_title'])) {
			$iter_count = count($instance['chart_item_title']);
		}
		if($iter_count > 0)	{
			for($i = 0; $i < $iter_count; $i++) {
				$chart_childs[] = array(
					'title' => $instance['chart_item_title'][$i],
					'level' => $instance['chart_item_level'][$i],
					'color' => $instance['chart_item_color'][$i]
				);
			}
		}
 		extract($args, EXTR_SKIP); 		
 				
		$output .= $before_widget;	
		$output .= '<div class="trex_chart '.$chart_type.'" id="'.$block_id.'">';
		$output .= $title;	
		$output .= trex_diagram_builder($block_id, $chart_type, $chart_childs, 256);
		$output .= '</div>';
		$output .= $after_widget;

		echo $output;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['type'] = strip_tags($new_instance['type']);
		
		if(!empty($new_instance['chart_item_title']) && !empty($new_instance['chart_item_level'])) {		
			$instance['chart_item_title'] = $new_instance['chart_item_title'];
			$instance['chart_item_level'] = $new_instance['chart_item_level'];
			$instance['chart_item_color'] = $new_instance['chart_item_color'];
		}
		if ( isset($alloptions['themerex_chart_widget']) )
			delete_option('themerex_chart_widget');

		return $instance;
	}
	function form( $instance ) {
		$title  = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$type  = isset( $instance['type'] ) ? esc_attr( $instance['type'] ) : '';
?>		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'themerex'); ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'type' ); ?>"><?php _e( 'Widget type', 'themerex' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'type' ); ?>" id="<?php echo $this->get_field_name( 'type' ); ?>">
				<option value="bar" <?php echo $type == 'bar' ? 'selected' : ''; ?>><?php _e( 'Bar', 'themerex' ); ?></option>
				<option value="circular" <?php echo $type == 'circular' ? 'selected' : ''; ?>><?php _e( 'Circular', 'themerex' ); ?></option>
			</select>
		</p>
		<script>
			jQuery(document).ready(function(){
				cloneClick();
			    jQuery('#widgets-right .colorpicker_field:not(.inited)').addClass('inited').wpColorPicker();
			});
		</script>
<?php 
	
	$item_count = !empty($instance['chart_item_title']) ? count($instance['chart_item_title']) : 1;
	
	for($i = 0; $i < $item_count; $i++) {
		
		if($i > 0 && empty($instance['chart_item_title'][$i])) continue;
		$chart_item_title = !empty($instance['chart_item_title'][$i]) ? $instance['chart_item_title'][$i] : '';
		$chart_item_level = !empty($instance['chart_item_level'][$i]) ? $instance['chart_item_level'][$i] : '';
		$chart_item_color = !empty($instance['chart_item_color'][$i]) ? $instance['chart_item_color'][$i] : '#00CBB1';
?>		
		<p class="chart_row clonable">
			<span class="chart_item_color">
				<label for="<?php echo $this->get_field_id( 'chart_item_color' ); ?>"><?php _e( 'Color:', 'themerex'); ?></label>
				<input class="widefat colorpicker_field" id="<?php echo $this->get_field_id( 'chart_item_color' ); ?>" name="<?php echo $this->get_field_name( 'chart_item_color' ); ?>[]" type="text" value="<?php echo $chart_item_color; ?>" />
			</span>
			<span class="chart_item_title">
				<label for="<?php echo $this->get_field_id( 'chart_item_title' ); ?>"><?php _e( 'Chart item title:', 'themerex'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'chart_item_title' ); ?>" name="<?php echo $this->get_field_name( 'chart_item_title' ); ?>[]" type="text" value="<?php echo $chart_item_title; ?>" />
			</span>
			<span class="chart_item_level">
				<label for="<?php echo $this->get_field_id( 'chart_item_level' ); ?>"><?php _e( 'Chart Item Level:', 'themerex'); ?></label>
				<input class="widefat" id="<?php echo $this->get_field_id( 'chart_item_level' ); ?>" name="<?php echo $this->get_field_name( 'chart_item_level' ); ?>[]" type="text" value="<?php echo $chart_item_level; ?>" />
			</span>
			<a href="#" class="clone">+</a>
		</p>
<?php
		}
	}
}